@@ -1,25 +1,10 @@
 /*
     This file is part of KDE.
 
-    Copyright (c) 2008 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2011 Laszlo Papp <djszapi@archlinux.us>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2008 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2011 Laszlo Papp <djszapi@archlinux.us>
 
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef ATTICA_PROVIDER_H
@@ -127,6 +112,33 @@ public:
     bool isEnabled() const;
     void setEnabled(bool enabled);
 
+    /**
+     * Set a custom identifier for your application (sent along with the requests as
+     * the http agent header in addition to the applicaiton name and version).
+     *
+     * For example, you might have an application named SomeApplication, version 23,
+     * and wish to send along the data "lookandfeel.knsrc". Call this function, and
+     * the resulting agent header would be:
+     *
+     * SomeApplication/23 (+lookandfeel.knsrc)
+     *
+     * If you do not set this (or set it to an empty string), the agent string becomes
+     *
+     * SomeApplication/23
+     *
+     * @param additionalAgentInformation The extra string
+     * @since 5.66
+     */
+    void setAdditionalAgentInformation(const QString& additionalInformation);
+    /**
+     * The custom identifier sent along with requests
+     *
+     * @return The custom identifier
+     * @see setAdditionalAgentInformation(const QString&)
+     * @since 5.66
+     */
+    QString additionalAgentInformation() const;
+
     /**
     A url that identifies this provider.
     This should be used as identifier when referring to this provider but you don't want to use the full provider object.
@@ -320,7 +332,6 @@ public:
     // Friend part of OCS
 
     ListJob<Person> *requestFriends(const QString &id, int page = 0, int pageSize = 20);
-    PostJob *postFriendInvitation(const QString &to, const QString &message);
     ListJob<Person> *requestSentInvitations(int page = 0, int pageSize = 20);
     ListJob<Person> *requestReceivedInvitations(int page = 0, int pageSize = 20);
     PostJob *inviteFriend(const QString &to, const QString &message);
@@ -706,6 +717,12 @@ private:
              const QString &person, const QString &friendV, const QString &message, const QString &achievements,
              const QString &activity, const QString &content, const QString &fan, const QString &forum,
              const QString &knowledgebase, const QString &event, const QString &comment, const QString &registerUrl);
+    // TODO KF6: merge with the constructor above (i.e. remove the above one - and actually do it this time :P )
+    Provider(PlatformDependent *internals, const QUrl &baseUrl, const QString &name, const QUrl &icon,
+             const QString &person, const QString &friendV, const QString &message, const QString &achievements,
+             const QString &activity, const QString &content, const QString &fan, const QString &forum,
+             const QString &knowledgebase, const QString &event, const QString &comment, const QString &registerUrl,
+             const QString &additionalAgentInformation);
 
     friend class ProviderManager;
 };
